# DataLakeAnalytics

> see https://aka.ms/autorest

This is the AutoRest configuration file for DataLakeAnalytics.



---
## Getting Started
To build the SDK for DataLakeAnalytics, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the DataLakeAnalytics API.

``` yaml
openapi-type: arm
tag: package-2016-11
```


### Tag: package-2016-11

These settings apply only when `--tag=package-2016-11` is specified on the command line.

``` yaml $(tag) == 'package-2016-11'
input-file:
- Microsoft.DataLakeAnalytics/stable/2016-11-01/account.json
```

### Tag: package-2015-10-preview

These settings apply only when `--tag=package-2015-10-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-10-preview'
input-file:
- Microsoft.DataLakeAnalytics/preview/2015-10-01-preview/account.json
```

## Suppression
``` yaml
directive:
  - suppress: TrackedResourceGetOperation
    reason: This is by design in that we return DataLakeAnalyticsAccountBasic only for Account_List
    #where:
    #  - $.definitions.DataLakeAnalyticsAccountBasic

  - suppress: TrackedResourcePatchOperation
    reason: DataLakeAnalyticsAccountBasic is not independent and its purpose is for Account_List only.  PATCH is for DataLakeAnalyticsAccount, which will effectively update DataLakeAnalyticsAccountBasic
    #where:
    #  - $.definitions.DataLakeAnalyticsAccountBasic
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_datalake_analytics']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DataLake.Analytics
  output-folder: $(csharp-sdks-folder)/DataLake.Analytics/Management.DataLake.Analytics/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.

```yaml $(python)
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  package-name: azure-mgmt-datalake-analytics
  clear-output-folder: true
  no-namespace-folders: true
  namespace: azure.mgmt.datalake.analytics.account
  output-folder: $(python-sdks-folder)/azure-mgmt-datalake-analytics/azure/mgmt/datalake/analytics/account
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.datalake.analytics
license-header: MICROSOFT_MIT_NO_CODEGEN
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-datalake/analytics
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-10-preview
  - tag: package-2016-11
```

### Tag: package-2015-10-preview and java

These settings apply only when `--tag=package-2015-10-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-10-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.datalakeanalytics.v2015_10_01_preview
  output-folder: $(azure-libraries-for-java-folder)/datalakeanalytics/resource-manager/v2015_10_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-11 and java

These settings apply only when `--tag=package-2016-11 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-11' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.datalakeanalytics.v2016_11_01
  output-folder: $(azure-libraries-for-java-folder)/datalakeanalytics/resource-manager/v2016_11_01
regenerate-manager: true
generate-interface: true
```


